@@ -16,7 +16,6 @@ from StringIO import StringIO as p_StringO
 from cStringIO import OutputType as c_StringO
 from uiautomatorplug.android import device, ExpectException
 
-
 log = logging.getLogger(__name__)
 '''global log instance'''
 LOCATION_NOT_FOUND_EXCEPTION = '%s not found.'
@@ -114,6 +113,24 @@ def _writeResultToFile(output, content):
     except:
         pass
 
+def _writeSSPIDToFile(path):
+    try:
+        serial = os.environ['ANDROID_SERIAL'] if os.environ.has_key('ANDROID_SERIAL') else None
+        bridge = _findExetuable('adb')
+        times = '?'
+        system_server_pid = '?'
+        if serial:
+            system_server_pid = AdbCommand('%s -s %s shell ps | grep system_server' % (bridge, serial)).run().strip().split()[1]
+            times = AdbCommand('%s -s %s shell date' % (bridge, serial)).run().strip()
+        else:
+            system_server_pid = AdbCommand('%s shell ps | grep system_server' % bridge).run().strip().split()[1]
+            times = AdbCommand('%s shell date' % bridge).run().strip()
+        pid_file = join(path, 'system_server_pid.txt')
+        with open(pid_file, 'a') as f:
+            f.write('%s -> %s' % (times, system_server_pid))
+    except:
+        pass
+
 def _calcScore(frame):
     """Calculates a score for this stack frame, so that can be used as a
     quality indicator to compare to other stack frames in selecting the
@@ -301,6 +318,7 @@ class FileOutputPlugin(nose.plugins.Plugin):
         
         tmp = join(os.getcwd(), 'tmp')
         case_report_dir = _mkdir(join(tmp, '%s%s%s' % (case_dir_name, '@', str(self.conf.case_start_time).replace(' ', '_'))))
+        _writeSSPIDToFile(case_report_dir)
         device.report_dir_path = case_report_dir
 
     def startTest(self, test):
@@ -313,6 +331,7 @@ class FileOutputPlugin(nose.plugins.Plugin):
             self.conf.update({'case_start_time': case_start_time})
         if self.write_hashes:
             sys.stderr.write('%s%s' % (str(case_start_time), ' '))
+        
 
     def stopTest(self, test):
         """
